# AppletHttp 使用文档

该模块集成了签名、获取 Token、重新获取 Token、格式化返回数据以及输出格式化日志等功能

## Usage

### 安装依赖

api-interceptor：

```shell
npm install git+ssh://git@git.verystar.cn:common/api-interceptor.git#v1.4.6

npm install git+ssh://git@git.verystar.cn:common/api-interceptor.git#Tag
```

`hash.js和applets-request-mode-list`：

```shell
npm install hash.js applets-request-mode-list
```

### Example

```javascript
import { getToken } from "mini-auth-v1";
import { appletHttp } from "api-interceptor";
import { IApis } from "api-interceptor/typings/AppletHttp.d";
import { getEnvData } from "../../utils/util";

// 接口配置
const apiList = {
  getDemo: {
    apiUrl: "/get/demo",
    method: "POST",
    /**
     * 重试次数
     *
     * 可选配置：默认2
     */
    retryTimes: 3,

    /**
     * 重试间隔时间
     *
     * 可选配置：默认2000
     */
    interval: 3000,
  },
};

appletHttp.addSignOptions({
  apiKey: "API_APP_KEY",
  apiCode: "API_APP_CODE",
});

appletHttp.addTokenFunction(getToken);

appletHttp.addCheckRetryExecutor((res) => {
  try {
    // 根据错误码判断是否需要重新获取token
    return [40003, 40005].includes(res?.data?.code);
  } catch (e) {
    console.error(e);
    return false;
  }
});

// 获取请求前日志
appletHttp.beforeRequestLog((log) => {
  console.log("beforeRequestLog: ", log);
});

// 获取响应的原始日志
appletHttp.afterResponseOriginalLog((log) => {
  console.log("afterResponseOriginalLog: ", log);
});

// 获取格式化后响应日志
appletHttp.afterResponseLog((log) => {
  console.log("afterResponseLog: ", log);
});

// 获取错误日志
appletHttp.addErrorLog((log) => {
  console.log("addErrorLog: ", log);
});

const api = appletHttp.getHttpIns<IApis<typeof apiList>>({
  baseURL: "{HOST}",
  apiList: apiList,
});

export default api.apis;
```
