import ApiHttp from "applets-request-mode-list";
interface ICreateApiHttpOptions {
    baseURL: string;
    apiList: Record<string, Record<string, any>>;
}
interface IOptions {
    apiKey: string;
    apiCode: string;
}
declare class AppletHttp {
    private apiKey;
    private apiCode;
    private getToken;
    private beforeLog;
    private afterOriginalLog;
    private errorLog;
    private afterLog;
    private checkRetry;
    /**
     * 添加签名数据
     * @param params 签名数据
     */
    addSignOptions(params: IOptions): void;
    /**
     * 添加获取token方法
     * @param getToken 获取token方法
     */
    addTokenFunction(getToken: any): void;
    /**
     * 添加检测是否需要重新获取token的方法
     * @param executor 检测是否需要重新获取token的方法
     */
    addCheckRetryExecutor(executor: (opts: any) => boolean): void;
    /**
     * 监听请求前的日志
     * @param {function} executor 获取请求前的日志
     * @returns
     */
    beforeRequestLog(executor: (opts: any) => void): void;
    /**
     * 监听响应的原始日志
     * @param executor 获取响应的原始日志
     */
    afterResponseOriginalLog(executor: (opts: any, apiConfig?: Record<string, any>) => void): void;
    /**
     * 监听响应后格式化日志
     * @param executor 获取响应后格式化日志
     */
    afterResponseLog(executor: (opts: any) => void): void;
    /**
     * 监听错误日志
     * @param executor 获取错误日志
     */
    addErrorLog(executor: (opts: any) => void): void;
    /**
     * 获取请求对象实例
     * @param options ICreateApiHttpOptions
     * @param reqConfig IAppletsRequestConfig
     */
    getHttpIns<T = null>(options: ICreateApiHttpOptions, reqConfig?: IAppletsRequestConfig): ApiHttp<T>;
}
export interface IAppletsResSuccess<IData = any> {
    code: number;
    msg: string;
    data: IData;
}
export declare type IApis<IApiFn> = {
    [K in keyof IApiFn]: IApiFn[K] extends {
        params: Record<string, any>;
    } ? <IParam>(opts: IAppletsRequestConfig<IParam>) => Promise<IAppletsResSuccess<any>> : (opts: IAppletsRequestConfig | void) => Promise<IAppletsResSuccess<any>>;
};
export declare type ICustomApis<IApiFn, IApiRes> = {
    [K in keyof IApiFn]: IApiFn[K] extends {
        params: Record<string, any>;
    } ? <IParam>(opts: IAppletsRequestConfig<IParam>) => Promise<IAppletsResSuccess<any>> : (opts: IAppletsRequestConfig | void) => Promise<IApiRes>;
};
declare const ins: AppletHttp;
export default ins;
export { AppletHttp };
